Tekmpesa - tekmpesa’s documentation! — tekmpesa 1.0.0 documentation

# Tekmpesa - tekmpesa’s documentation!

Tekmpesa is an open-source Python SDK supporting 5 Countries for the MPESA mobile money platform. It was designed to provide a simple, clear, and concise interface to quickly integrate MPESA payments into python applications.

## Features

- Simple, Clean, and Consistent API

- Supports MPESA Across 5 Countries in Africa.

- `mpesa.kenya`

- `mpesa.ghana`

- `mpesa.tanzania`

- `mpesa.mozambique`

- `mpesa.drc`

Supported Countries.
Country | Supported
--- | ---
Kenya | YES
Tanzania | YES
Ghana | YES
Democratic Republic of Congo (DRC) | YES
Mozambique | YES
Egypt | NO
Lesotho | NO

Table Of Contents:

- Overview
  - Installation
  - Usage
  - Configuration
  - Examples
- API Reference
  - mpesa.kenya
  - mpesa.tanzania
  - mpesa.ghana
  - mpesa.mozambique
  - mpesa.drc
  - mpesa.egypt
  - mpesa.lesotho
  - mpesa.portalsdk

# Indices and tables

- Index

- Module Index

- Search Page